@@ -39,7 +39,10 @@ class Failure(Exception):
     This class is only rarely raised by itself; most of the time `.Runner.run`
     (or a wrapper of same, such as `.Context.sudo`) will raise a specific
     subclass like `UnexpectedExit` or `AuthFailure`.
+
+    .. versionadded:: 1.0
     """
+
     def __init__(self, result, reason=None):
         self.result = result
         self.reason = reason
@@ -64,25 +67,26 @@ class UnexpectedExit(Failure):
     - The last 10 lines of stdout, if it was hidden;
     - The last 10 lines of stderr, if it was hidden and non-empty (e.g.
       pty=False; when pty=True, stderr never happens.)
+
+    .. versionadded:: 1.0
     """
+
     def __str__(self):
-        already_printed = ' already printed'
-        if 'stdout' not in self.result.hide:
+        already_printed = " already printed"
+        if "stdout" not in self.result.hide:
             stdout = already_printed
         else:
             stdout = encode_output(
-                _tail(self.result.stdout),
-                self.result.encoding,
+                _tail(self.result.stdout), self.result.encoding
             )
         if self.result.pty:
             stderr = " n/a (PTYs have no stderr)"
         else:
-            if 'stderr' not in self.result.hide:
+            if "stderr" not in self.result.hide:
                 stderr = already_printed
             else:
                 stderr = encode_output(
-                    _tail(self.result.stderr),
-                    self.result.encoding,
+                    _tail(self.result.stderr), self.result.encoding
                 )
         command = self.result.command
         exited = self.result.exited
@@ -103,9 +107,7 @@ Stderr:{}
         # TODO: expand?
         template = "<{}: cmd={!r} exited={}>"
         return template.format(
-            self.__class__.__name__,
-            self.result.command,
-            self.result.exited,
+            self.__class__.__name__, self.result.command, self.result.exited
         )
 
 
@@ -117,7 +119,10 @@ class AuthFailure(Failure):
         `.Result` objects attached to these exceptions typically lack exit code
         information, since the command was never fully executed - the exception
         was raised instead.
+
+    .. versionadded:: 1.0
     """
+
     def __init__(self, result, prompt):
         self.result = result
         self.prompt = prompt
@@ -132,7 +137,10 @@ class ParseError(Exception):
     An error arising from the parsing of command-line flags/arguments.
 
     Ambiguous input, invalid task names, invalid flags, etc.
+
+    .. versionadded:: 1.0
     """
+
     def __init__(self, msg, context=None):
         super(ParseError, self).__init__(msg)
         self.context = context
@@ -155,7 +163,10 @@ class Exit(Exception):
     If ``message`` (a string) given, it is printed to standard error, and the
     program exits with code ``1`` by default (unless overridden by also giving
     ``code`` explicitly.)
+
+    .. versionadded:: 1.0
     """
+
     def __init__(self, message=None, code=None):
         self.message = message
         self._code = code
@@ -175,14 +186,20 @@ class PlatformError(Exception):
     module.
 
     Typically used to present a clearer error message to the user.
+
+    .. versionadded:: 1.0
     """
+
     pass
 
 
 class AmbiguousEnvVar(Exception):
     """
     Raised when loading env var config keys has an ambiguous target.
+
+    .. versionadded:: 1.0
     """
+
     pass
 
 
@@ -192,14 +209,35 @@ class UncastableEnvVar(Exception):
 
     E.g. trying to stuff ``MY_VAR="foo"`` into ``{'my_var': ['uh', 'oh']}``
     doesn't make any sense until/if we implement some sort of transform option.
+
+    .. versionadded:: 1.0
     """
+
     pass
 
 
 class UnknownFileType(Exception):
     """
     A config file of an unknown type was specified and cannot be loaded.
+
+    .. versionadded:: 1.0
     """
+
+    pass
+
+
+class UnpicklableConfigMember(Exception):
+    """
+    A config file contained module objects, which can't be pickled/copied.
+
+    We raise this more easily catchable exception instead of letting the
+    (unclearly phrased) TypeError bubble out of the pickle module. (However, to
+    avoid our own fragile catching of that error, we head it off by explicitly
+    testing for module members.)
+
+    .. versionadded:: 1.0.2
+    """
+
     pass
 
 
@@ -213,17 +251,18 @@ def _printable_kwargs(kwargs):
     printable = {}
     for key, value in six.iteritems(kwargs):
         item = value
-        if key == 'args':
+        if key == "args":
             item = []
             for arg in value:
                 new_arg = arg
-                if hasattr(arg, '__len__') and len(arg) > 10:
+                if hasattr(arg, "__len__") and len(arg) > 10:
                     msg = "<... remainder truncated during error display ...>"
                     new_arg = arg[:10] + [msg]
                 item.append(new_arg)
         printable[key] = item
     return printable
 
+
 class ThreadException(Exception):
     """
     One or more exceptions were raised within background threads.
@@ -234,7 +273,10 @@ class ThreadException(Exception):
     .. note::
         Threads which did not encounter an exception, do not contribute to this
         exception object and thus are not present inside `exceptions`.
+
+    .. versionadded:: 1.0
     """
+
     #: A tuple of `ExceptionWrappers <invoke.util.ExceptionWrapper>` containing
     #: the initial thread constructor kwargs (because `threading.Thread`
     #: subclasses should always be called with kwargs) and the caught exception
@@ -257,10 +299,12 @@ class ThreadException(Exception):
         for x in self.exceptions:
             # Build useful display
             detail = "Thread args: {}\n\n{}"
-            details.append(detail.format(
-                pformat(_printable_kwargs(x.kwargs)),
-                "\n".join(format_exception(x.type, x.value, x.traceback)),
-            ))
+            details.append(
+                detail.format(
+                    pformat(_printable_kwargs(x.kwargs)),
+                    "\n".join(format_exception(x.type, x.value, x.traceback)),
+                )
+            )
         args = (
             len(self.exceptions),
             ", ".join(x.type.__name__ for x in self.exceptions),
@@ -271,7 +315,9 @@ Saw {} exceptions within threads ({}):
 
 
 {}
-""".format(*args)
+""".format(
+            *args
+        )
 
 
 class WatcherError(Exception):
@@ -285,7 +331,10 @@ class WatcherError(Exception):
     `.Runner` catches these and attaches them to `.Failure` exceptions so they
     can be referenced by intermediate code and/or act as extra info for end
     users.
+
+    .. versionadded:: 1.0
     """
+
     pass
 
 
@@ -295,5 +344,8 @@ class ResponseNotAccepted(WatcherError):
 
     Mostly used by `.FailingResponder` and subclasses, e.g. "oh dear I
     autosubmitted a sudo password and it was incorrect."
+
+    .. versionadded:: 1.0
     """
+
     pass
